@@ -411,6 +411,33 @@ reload_screen_info (CsScreen *screen)
     screen->rect.height = gdk_screen_get_height (screen->gdk_screen);
 }
 
+static gboolean
+is_full_change (CsScreen *screen)
+{
+    // Check to see if the union of monitor rects is the same size as the screen
+
+    GdkRectangle total_monitors = {0};
+    gint i;
+    gboolean same;
+
+    for (i = 0; i < screen->n_monitor_infos; i++)
+    {
+        CsMonitorInfo info = screen->monitor_infos[i];
+
+        gdk_rectangle_union (&total_monitors, &info.rect, &total_monitors);
+    }
+
+    same = gdk_rectangle_equal (&total_monitors, &screen->rect);
+
+    g_printerr ("Screen rect (%d,%d-%dx%d) and %d monitor rects (%d,%d-%dx%d) %s\n",
+                screen->rect.x, screen->rect.y, screen->rect.width, screen->rect.height,
+                screen->n_monitor_infos,
+                total_monitors.x, total_monitors.y, total_monitors.width, total_monitors.height,
+                same ? "add up, sending change notification" : "DO NOT add up, skipping change notification");
+
+    return same;
+}
+
 static void
 on_monitors_changed (GdkScreen *gdk_screen, gpointer user_data)
 {
@@ -427,7 +454,10 @@ on_monitors_changed (GdkScreen *gdk_screen, gpointer user_data)
     g_free (old_monitor_infos);
     reload_screen_info (screen);
 
-    g_signal_emit (screen, signals[SCREEN_MONITORS_CHANGED], 0);
+    if (is_full_change (screen))
+    {
+        g_signal_emit (screen, signals[SCREEN_MONITORS_CHANGED], 0);
+    }
 }
 
 static void
@@ -446,7 +476,10 @@ on_screen_changed (GdkScreen *gdk_screen, gpointer user_data)
     g_free (old_monitor_infos);
     reload_screen_info (screen);
 
-    g_signal_emit (screen, signals[SCREEN_SIZE_CHANGED], 0);
+    if (is_full_change (screen))
+    {
+        g_signal_emit (screen, signals[SCREEN_SIZE_CHANGED], 0);
+    }
 }
 
 static void
@@ -789,6 +822,63 @@ cs_screen_place_pointer_in_primary_monitor (CsScreen *screen)
                      rect.y + (rect.height * .75));
 }
 
+/**
+ * cs_screen_set_net_wm_name:
+ * @window: The #GdkWindow to set the property on
+ * @name: The name.
+ *
+ * Sets _NET_WM_NAME to name on window
+ */
+void
+cs_screen_set_net_wm_name (GdkWindow   *window,
+                           const gchar *name)
+{
+    GdkDisplay *display = gdk_display_get_default ();
+    Window xwindow = gdk_x11_window_get_xid (window);
+
+    XChangeProperty (GDK_DISPLAY_XDISPLAY (display), xwindow,
+                     gdk_x11_get_xatom_by_name_for_display (display, "_NET_WM_NAME"),
+                     gdk_x11_get_xatom_by_name_for_display (display, "UTF8_STRING"), 8,
+                     PropModeReplace, (guchar *)name, strlen (name));
+
+    XFlush(GDK_DISPLAY_XDISPLAY (display));
+}
+
+/**
+ * cs_screen_get_net_wm_name:
+ * @xwindow: The Window (XID) to get the property from.
+ *
+ * Gets the NET_WM_NAME of xwindow
+ * 
+ * returns: (transfer full): The value of NET_WM_NAME.
+ */
+gchar *
+cs_screen_get_net_wm_name (gulong xwindow)
+{
+    GdkDisplay *display = gdk_display_get_default ();
+    Atom net_wm_name_atom;
+    Atom type;
+    int format;
+    unsigned long nitems, after;
+    unsigned char *data = NULL;
+    gchar *name = NULL;
+
+    net_wm_name_atom = XInternAtom(GDK_DISPLAY_XDISPLAY (display), "_NET_WM_NAME", False);
+
+    XGetWindowProperty(GDK_DISPLAY_XDISPLAY (display),
+                       xwindow,
+                       net_wm_name_atom, 0, 256,
+                       False, AnyPropertyType,
+                       &type, &format, &nitems, &after,
+                       &data);
+    if (data) {
+       name = g_strdup((char *) data);
+       XFree(data);
+    }
+
+    return name;
+}
+
 /**
  * cs_screen_reset_screensaver:
  *
@@ -801,3 +891,28 @@ cs_screen_reset_screensaver (void)
 {
     XResetScreenSaver (GDK_DISPLAY_XDISPLAY (gdk_display_get_default ()));
 }
+
+/**
+ * cs_screen_get_global_scale:
+ *
+ * Retrieves the global scale factor from the GdkScreen.
+ *
+ */
+gint
+cs_screen_get_global_scale (void)
+{
+    GdkScreen *gdkscreen;
+    GValue value = G_VALUE_INIT;
+    gint window_scale = 1;
+
+    gdkscreen = gdk_screen_get_default ();
+
+    g_value_init (&value, G_TYPE_INT);
+
+    if (gdk_screen_get_setting (gdkscreen, "gdk-window-scaling-factor", &value))
+    {
+        window_scale = g_value_get_int (&value);
+    }
+
+    return window_scale;
+}
\ No newline at end of file
